# Generated by Django 5.2.15 on 2026-06-15 21:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0015_alter_assignmentitempolicy_allowed_meta_groups_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='assignmentitempolicy',
            name='attribute_bounds',
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AddField(
            model_name='doctrinefititem',
            name='attribute_bounds',
            field=models.JSONField(blank=True, default=dict, help_text='Optional per-attribute abyssal acceptance window: {attr_id: {min, max}}. The worst-side bound is the pass threshold; absent = meet-or-beat the baseline.'),
        ),
        migrations.AddField(
            model_name='fitsubmission',
            name='esi_ship_item_id',
            field=models.PositiveBigIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='sdetype',
            name='market_group_id',
            field=models.PositiveIntegerField(blank=True, db_index=True, null=True),
        ),
    ]
