# Generated by Django 5.2.15 on 2026-06-15 19:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0013_backfill_meta_groups'),
    ]

    operations = [
        migrations.AlterField(
            model_name='assignmentitempolicy',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
        migrations.AlterField(
            model_name='compliancefinding',
            name='section',
            field=models.CharField(blank=True, choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], default='', max_length=8),
        ),
        migrations.AlterField(
            model_name='doctrinefititem',
            name='allowed_meta_groups',
            field=models.JSONField(blank=True, default=list, help_text='Meta group IDs allowed as substitutes (checked = allowed). Empty = no family substitutes.'),
        ),
        migrations.AlterField(
            model_name='doctrinefititem',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
        migrations.AlterField(
            model_name='policyslotrule',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
        migrations.AlterField(
            model_name='sdetype',
            name='slot_kind',
            field=models.CharField(choices=[('HIGH', 'High slot module'), ('MED', 'Mid slot module'), ('LOW', 'Low slot module'), ('RIG', 'Rig'), ('SUBSYS', 'Subsystem'), ('DRONE', 'Drone'), ('FIGHTER', 'Fighter'), ('CHARGE', 'Charge'), ('SHIP', 'Ship'), ('IMPLANT', 'Implant'), ('BOOSTER', 'Booster'), ('OTHER', 'Other')], default='OTHER', max_length=8),
        ),
        migrations.AlterField(
            model_name='submissionitem',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
    ]
