# Generated by Django 5.2.15 on 2026-06-16 20:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0018_doctrinecategory_visibility'),
    ]

    operations = [
        migrations.AlterField(
            model_name='assignmentitempolicy',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('FUEL', 'Fuel bay'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
        migrations.AlterField(
            model_name='compliancefinding',
            name='section',
            field=models.CharField(blank=True, choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('FUEL', 'Fuel bay'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], default='', max_length=8),
        ),
        migrations.AlterField(
            model_name='doctrinefititem',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('FUEL', 'Fuel bay'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
        migrations.AlterField(
            model_name='policyslotrule',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('FUEL', 'Fuel bay'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
        migrations.AlterField(
            model_name='sdetype',
            name='slot_kind',
            field=models.CharField(choices=[('HIGH', 'High slot module'), ('MED', 'Mid slot module'), ('LOW', 'Low slot module'), ('RIG', 'Rig'), ('SUBSYS', 'Subsystem'), ('DRONE', 'Drone'), ('FIGHTER', 'Fighter'), ('CHARGE', 'Charge'), ('SHIP', 'Ship'), ('IMPLANT', 'Implant'), ('BOOSTER', 'Booster'), ('FUEL', 'Fuel'), ('OTHER', 'Other')], default='OTHER', max_length=8),
        ),
        migrations.AlterField(
            model_name='submissionitem',
            name='section',
            field=models.CharField(choices=[('HIGH', 'High slots'), ('MED', 'Mid slots'), ('LOW', 'Low slots'), ('RIG', 'Rigs'), ('SUBSYS', 'Subsystems'), ('DRONE', 'Drone bay'), ('FIGHTER', 'Fighter bay'), ('CARGO', 'Cargo'), ('FUEL', 'Fuel bay'), ('IMPLANT', 'Implants'), ('BOOSTER', 'Boosters')], max_length=8),
        ),
    ]
