# Generated by Django 5.2.15 on 2026-06-17 20:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0022_compliancepolicy_is_builtin'),
    ]

    operations = [
        migrations.AddField(
            model_name='compliancepolicy',
            name='disabled_at',
            field=models.DateTimeField(blank=True, help_text="When this policy was disabled. Disabled policies can't be applied to fittings.", null=True),
        ),
    ]
