# Generated by Django 5.2.15 on 2026-07-06 21:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0031_doctrinefit_source_policy_bumped_at_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='ScanParameters',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('member_scan_esi_budget', models.PositiveIntegerField(default=25)),
                ('audit_ships_per_post', models.PositiveIntegerField(default=50)),
                ('abyssal_lookups_per_ship', models.PositiveIntegerField(default=25)),
                ('results_per_page', models.PositiveIntegerField(default=50)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'verbose_name': 'Scan parameters',
                'verbose_name_plural': 'Scan parameters',
            },
        ),
    ]
