# Generated by Django 5.2.15 on 2026-07-02 16:38

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0028_structurenamecache'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='assignmentitempolicy',
            name='min_meta_level',
        ),
        migrations.RemoveField(
            model_name='doctrinefititem',
            name='min_meta_level',
        ),
        migrations.RemoveField(
            model_name='policyslotrule',
            name='min_meta_level',
        ),
    ]
